<?php

require_once 'Doctrine/DBAL/autoload.php'; // (already *included* by Symfony/Bridge/Doctrine)
// require_once 'Doctrine/Persistence/autoload.php'; (already required by Symfony/Bridge/Doctrine)
require_once 'Doctrine/SqlFormatter/autoload.php';
// require_once 'Symfony/Component/Cache/autoload.php'; (already required by Symfony/Bundle/FrameworkBundle)
// require_once 'Symfony/Component/Config/autoload.php'; (already required by Symfony/Bundle/FrameworkBundle)
require_once 'Symfony/Component/Console/autoload.php'; // (already *included* by Symfony/Bundle/FrameworkBundle)
// require_once 'Symfony/Component/DependencyInjection/autoload.php'; (already required by Symfony/Bundle/FrameworkBundle)
require_once 'Symfony/Bridge/Doctrine/autoload.php';
require_once 'Symfony/Bundle/FrameworkBundle/autoload.php';
// require_once 'Symfony/Contracts/Service/autoload.php'; (already required by Symfony/Component/Cache)

// include_once 'Doctrine/ORM/autoload.php'; (already included by Symfony/Bridge/Doctrine)
if (stream_resolve_include_path('Symfony/Bundle/WebProfilerBundle/autoload.php')){
    include_once 'Symfony/Bundle/WebProfilerBundle/autoload.php';
}

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    true,
    false
);
// @codeCoverageIgnoreEnd
